settings

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 28, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	RegisterPushSubscription_PushType_name = map[int32]string{
		0: "UNKNOWN",
		1: "WEB",
		2: "IOS",
		3: "ANDROID_FCM",
	}
	RegisterPushSubscription_PushType_value = map[string]int32{
		"UNKNOWN":     0,
		"WEB":         1,
		"IOS":         2,
		"ANDROID_FCM": 3,
	}
)

Enum value maps for RegisterPushSubscription_PushType.

var (
	RegisterPushSubscription_PushEncryptionScheme_name = map[int32]string{
		0: "PUSH_ENCRYPTION_UNKNOWN",
		1: "P256_HKDF_SHA256_AES256GCM_V1",
	}
	RegisterPushSubscription_PushEncryptionScheme_value = map[string]int32{
		"PUSH_ENCRYPTION_UNKNOWN":       0,
		"P256_HKDF_SHA256_AES256GCM_V1": 1,
	}
)

Enum value maps for RegisterPushSubscription_PushEncryptionScheme.

var File_settings_proto protoreflect.FileDescriptor

Functions

This section is empty.

Types

type Account

type Account struct {
	Email         *string `protobuf:"bytes,1,opt,name=email,proto3,oneof" json:"email,omitempty"`
	Confirmed     bool    `protobuf:"varint,2,opt,name=confirmed,proto3" json:"confirmed,omitempty"`
	HasPassword   bool    `protobuf:"varint,3,opt,name=has_password,json=hasPassword,proto3" json:"has_password,omitempty"`
	TotpEnabled   bool    `protobuf:"varint,4,opt,name=totp_enabled,json=totpEnabled,proto3" json:"totp_enabled,omitempty"`
	PendingDelete bool    `protobuf:"varint,5,opt,name=pending_delete,json=pendingDelete,proto3" json:"pending_delete,omitempty"`
	// contains filtered or unexported fields
}

func (*Account) Descriptor deprecated

func (*Account) Descriptor() ([]byte, []int)

Deprecated: Use Account.ProtoReflect.Descriptor instead.

func (*Account) GetConfirmed

func (x *Account) GetConfirmed() bool

func (*Account) GetEmail

func (x *Account) GetEmail() string

func (*Account) GetHasPassword

func (x *Account) GetHasPassword() bool

func (*Account) GetPendingDelete

func (x *Account) GetPendingDelete() bool

func (*Account) GetTotpEnabled

func (x *Account) GetTotpEnabled() bool

func (*Account) ProtoMessage

func (*Account) ProtoMessage()

func (*Account) ProtoReflect

func (x *Account) ProtoReflect() protoreflect.Message

func (*Account) Reset

func (x *Account) Reset()

func (*Account) String

func (x *Account) String() string

type BackupCode

type BackupCode struct {
	Code string `protobuf:"bytes,1,opt,name=code,proto3" json:"code,omitempty"`
	Used bool   `protobuf:"varint,2,opt,name=used,proto3" json:"used,omitempty"`
	// contains filtered or unexported fields
}

func (*BackupCode) Descriptor deprecated

func (*BackupCode) Descriptor() ([]byte, []int)

Deprecated: Use BackupCode.ProtoReflect.Descriptor instead.

func (*BackupCode) GetCode

func (x *BackupCode) GetCode() string

func (*BackupCode) GetUsed

func (x *BackupCode) GetUsed() bool

func (*BackupCode) ProtoMessage

func (*BackupCode) ProtoMessage()

func (*BackupCode) ProtoReflect

func (x *BackupCode) ProtoReflect() protoreflect.Message

func (*BackupCode) Reset

func (x *BackupCode) Reset()

func (*BackupCode) String

func (x *BackupCode) String() string

type BeginMfaStepUp

type BeginMfaStepUp struct {
	Password string `protobuf:"bytes,1,opt,name=password,proto3" json:"password,omitempty"`
	// contains filtered or unexported fields
}

settings.beginMfaStepUp -> settings.MfaStepUp

func (*BeginMfaStepUp) Descriptor deprecated

func (*BeginMfaStepUp) Descriptor() ([]byte, []int)

Deprecated: Use BeginMfaStepUp.ProtoReflect.Descriptor instead.

func (*BeginMfaStepUp) GetPassword

func (x *BeginMfaStepUp) GetPassword() string

func (*BeginMfaStepUp) ProtoMessage

func (*BeginMfaStepUp) ProtoMessage()

func (*BeginMfaStepUp) ProtoReflect

func (x *BeginMfaStepUp) ProtoReflect() protoreflect.Message

func (*BeginMfaStepUp) Reset

func (x *BeginMfaStepUp) Reset()

func (*BeginMfaStepUp) String

func (x *BeginMfaStepUp) String() string

type ChangeEmail

type ChangeEmail struct {
	NewEmail string `protobuf:"bytes,1,opt,name=new_email,json=newEmail,proto3" json:"new_email,omitempty"`
	// contains filtered or unexported fields
}

settings.changeEmail -> ()

func (*ChangeEmail) Descriptor deprecated

func (*ChangeEmail) Descriptor() ([]byte, []int)

Deprecated: Use ChangeEmail.ProtoReflect.Descriptor instead.

func (*ChangeEmail) GetNewEmail

func (x *ChangeEmail) GetNewEmail() string

func (*ChangeEmail) ProtoMessage

func (*ChangeEmail) ProtoMessage()

func (*ChangeEmail) ProtoReflect

func (x *ChangeEmail) ProtoReflect() protoreflect.Message

func (*ChangeEmail) Reset

func (x *ChangeEmail) Reset()

func (*ChangeEmail) String

func (x *ChangeEmail) String() string

type ChangeNotificationPreferences

type ChangeNotificationPreferences struct {
	Prefs types.NotifPrefs `protobuf:"varint,1,opt,name=prefs,proto3,enum=osmium.client.types.NotifPrefs" json:"prefs,omitempty"`
	// Types that are valid to be assigned to Scope:
	//
	//	*ChangeNotificationPreferences_ChatRef
	//	*ChangeNotificationPreferences_CommunityId
	Scope isChangeNotificationPreferences_Scope `protobuf_oneof:"scope"`
	// contains filtered or unexported fields
}

settings.changeNotificationPreferences -> ()

func (*ChangeNotificationPreferences) Descriptor deprecated

func (*ChangeNotificationPreferences) Descriptor() ([]byte, []int)

Deprecated: Use ChangeNotificationPreferences.ProtoReflect.Descriptor instead.

func (*ChangeNotificationPreferences) GetChatRef

func (x *ChangeNotificationPreferences) GetChatRef() *refs.ChatRef

func (*ChangeNotificationPreferences) GetCommunityId

func (x *ChangeNotificationPreferences) GetCommunityId() uint64

func (*ChangeNotificationPreferences) GetPrefs

func (*ChangeNotificationPreferences) GetScope

func (x *ChangeNotificationPreferences) GetScope() isChangeNotificationPreferences_Scope

func (*ChangeNotificationPreferences) ProtoMessage

func (*ChangeNotificationPreferences) ProtoMessage()

func (*ChangeNotificationPreferences) ProtoReflect

func (*ChangeNotificationPreferences) Reset

func (x *ChangeNotificationPreferences) Reset()

func (*ChangeNotificationPreferences) String

type ChangeNotificationPreferences_ChatRef

type ChangeNotificationPreferences_ChatRef struct {
	ChatRef *refs.ChatRef `protobuf:"bytes,2,opt,name=chat_ref,json=chatRef,proto3,oneof"` // For channel or DM chat
}

type ChangeNotificationPreferences_CommunityId

type ChangeNotificationPreferences_CommunityId struct {
	// @snowflake<Community>
	CommunityId uint64 `protobuf:"fixed64,3,opt,name=community_id,json=communityId,proto3,oneof"` // For community-level default
}

type ChangePassword

type ChangePassword struct {
	CurrentPassword string `protobuf:"bytes,1,opt,name=current_password,json=currentPassword,proto3" json:"current_password,omitempty"`
	NewPassword     string `protobuf:"bytes,2,opt,name=new_password,json=newPassword,proto3" json:"new_password,omitempty"`
	RevokeSessions  bool   `protobuf:"varint,3,opt,name=revoke_sessions,json=revokeSessions,proto3" json:"revoke_sessions,omitempty"` // Revoke all other sessions after password change
	// contains filtered or unexported fields
}

settings.changePassword -> ()

func (*ChangePassword) Descriptor deprecated

func (*ChangePassword) Descriptor() ([]byte, []int)

Deprecated: Use ChangePassword.ProtoReflect.Descriptor instead.

func (*ChangePassword) GetCurrentPassword

func (x *ChangePassword) GetCurrentPassword() string

func (*ChangePassword) GetNewPassword

func (x *ChangePassword) GetNewPassword() string

func (*ChangePassword) GetRevokeSessions

func (x *ChangePassword) GetRevokeSessions() bool

func (*ChangePassword) ProtoMessage

func (*ChangePassword) ProtoMessage()

func (*ChangePassword) ProtoReflect

func (x *ChangePassword) ProtoReflect() protoreflect.Message

func (*ChangePassword) Reset

func (x *ChangePassword) Reset()

func (*ChangePassword) String

func (x *ChangePassword) String() string

type ChangeStatus

type ChangeStatus struct {
	Status     types.UserStatus_Status      `protobuf:"varint,2,opt,name=status,proto3,enum=osmium.client.types.UserStatus_Status" json:"status,omitempty"`
	Activities []*types.UserStatus_Activity `protobuf:"bytes,3,rep,name=activities,proto3" json:"activities,omitempty"`
	LastActive *uint64                      `protobuf:"fixed64,4,opt,name=last_active,json=lastActive,proto3,oneof" json:"last_active,omitempty"`
	// contains filtered or unexported fields
}

settings.changeStatus -> ()

func (*ChangeStatus) Descriptor deprecated

func (*ChangeStatus) Descriptor() ([]byte, []int)

Deprecated: Use ChangeStatus.ProtoReflect.Descriptor instead.

func (*ChangeStatus) GetActivities

func (x *ChangeStatus) GetActivities() []*types.UserStatus_Activity

func (*ChangeStatus) GetLastActive

func (x *ChangeStatus) GetLastActive() uint64

func (*ChangeStatus) GetStatus

func (x *ChangeStatus) GetStatus() types.UserStatus_Status

func (*ChangeStatus) ProtoMessage

func (*ChangeStatus) ProtoMessage()

func (*ChangeStatus) ProtoReflect

func (x *ChangeStatus) ProtoReflect() protoreflect.Message

func (*ChangeStatus) Reset

func (x *ChangeStatus) Reset()

func (*ChangeStatus) String

func (x *ChangeStatus) String() string

type CompleteMfaStepUp

type CompleteMfaStepUp struct {
	ChallengeId string `protobuf:"bytes,1,opt,name=challenge_id,json=challengeId,proto3" json:"challenge_id,omitempty"`
	// Types that are valid to be assigned to Proof:
	//
	//	*CompleteMfaStepUp_Totp
	//	*CompleteMfaStepUp_RecoveryCode
	//	*CompleteMfaStepUp_WebauthnCredentialJson
	Proof isCompleteMfaStepUp_Proof `protobuf_oneof:"proof"`
	// contains filtered or unexported fields
}

settings.completeMfaStepUp -> settings.MfaStepUp

func (*CompleteMfaStepUp) Descriptor deprecated

func (*CompleteMfaStepUp) Descriptor() ([]byte, []int)

Deprecated: Use CompleteMfaStepUp.ProtoReflect.Descriptor instead.

func (*CompleteMfaStepUp) GetChallengeId

func (x *CompleteMfaStepUp) GetChallengeId() string

func (*CompleteMfaStepUp) GetProof

func (x *CompleteMfaStepUp) GetProof() isCompleteMfaStepUp_Proof

func (*CompleteMfaStepUp) GetRecoveryCode

func (x *CompleteMfaStepUp) GetRecoveryCode() string

func (*CompleteMfaStepUp) GetTotp

func (x *CompleteMfaStepUp) GetTotp() string

func (*CompleteMfaStepUp) GetWebauthnCredentialJson

func (x *CompleteMfaStepUp) GetWebauthnCredentialJson() string

func (*CompleteMfaStepUp) ProtoMessage

func (*CompleteMfaStepUp) ProtoMessage()

func (*CompleteMfaStepUp) ProtoReflect

func (x *CompleteMfaStepUp) ProtoReflect() protoreflect.Message

func (*CompleteMfaStepUp) Reset

func (x *CompleteMfaStepUp) Reset()

func (*CompleteMfaStepUp) String

func (x *CompleteMfaStepUp) String() string

type CompleteMfaStepUp_RecoveryCode

type CompleteMfaStepUp_RecoveryCode struct {
	RecoveryCode string `protobuf:"bytes,3,opt,name=recovery_code,json=recoveryCode,proto3,oneof"`
}

type CompleteMfaStepUp_Totp

type CompleteMfaStepUp_Totp struct {
	Totp string `protobuf:"bytes,2,opt,name=totp,proto3,oneof"`
}

type CompleteMfaStepUp_WebauthnCredentialJson

type CompleteMfaStepUp_WebauthnCredentialJson struct {
	WebauthnCredentialJson string `protobuf:"bytes,4,opt,name=webauthn_credential_json,json=webauthnCredentialJson,proto3,oneof"`
}

type DeleteAccount

type DeleteAccount struct {
	Cancel *bool `protobuf:"varint,1,opt,name=cancel,proto3,oneof" json:"cancel,omitempty"`
	// contains filtered or unexported fields
}

settings.deleteAccount -> ()

func (*DeleteAccount) Descriptor deprecated

func (*DeleteAccount) Descriptor() ([]byte, []int)

Deprecated: Use DeleteAccount.ProtoReflect.Descriptor instead.

func (*DeleteAccount) GetCancel

func (x *DeleteAccount) GetCancel() bool

func (*DeleteAccount) ProtoMessage

func (*DeleteAccount) ProtoMessage()

func (*DeleteAccount) ProtoReflect

func (x *DeleteAccount) ProtoReflect() protoreflect.Message

func (*DeleteAccount) Reset

func (x *DeleteAccount) Reset()

func (*DeleteAccount) String

func (x *DeleteAccount) String() string

type EditProfile

type EditProfile struct {
	Name     *string `protobuf:"bytes,1,opt,name=name,proto3,oneof" json:"name,omitempty"`
	Username *string `protobuf:"bytes,2,opt,name=username,proto3,oneof" json:"username,omitempty"`
	Bio      *string `protobuf:"bytes,3,opt,name=bio,proto3,oneof" json:"bio,omitempty"`
	// @snowflake<Emoji>
	Icon  *uint64 `protobuf:"fixed64,4,opt,name=icon,proto3,oneof" json:"icon,omitempty"`
	Color *uint32 `protobuf:"varint,5,opt,name=color,proto3,oneof" json:"color,omitempty"`
	// Packed RGB colors: first color in bits 0-23, second color in bits 24-47.
	ThemeColor        *uint64 `protobuf:"varint,6,opt,name=theme_color,json=themeColor,proto3,oneof" json:"theme_color,omitempty"`
	ShowBannerInVoice *bool   `protobuf:"varint,7,opt,name=show_banner_in_voice,json=showBannerInVoice,proto3,oneof" json:"show_banner_in_voice,omitempty"`
	// contains filtered or unexported fields
}

settings.editProfile -> ()

func (*EditProfile) Descriptor deprecated

func (*EditProfile) Descriptor() ([]byte, []int)

Deprecated: Use EditProfile.ProtoReflect.Descriptor instead.

func (*EditProfile) GetBio

func (x *EditProfile) GetBio() string

func (*EditProfile) GetColor

func (x *EditProfile) GetColor() uint32

func (*EditProfile) GetIcon

func (x *EditProfile) GetIcon() uint64

func (*EditProfile) GetName

func (x *EditProfile) GetName() string

func (*EditProfile) GetShowBannerInVoice

func (x *EditProfile) GetShowBannerInVoice() bool

func (*EditProfile) GetThemeColor

func (x *EditProfile) GetThemeColor() uint64

func (*EditProfile) GetUsername

func (x *EditProfile) GetUsername() string

func (*EditProfile) ProtoMessage

func (*EditProfile) ProtoMessage()

func (*EditProfile) ProtoReflect

func (x *EditProfile) ProtoReflect() protoreflect.Message

func (*EditProfile) Reset

func (x *EditProfile) Reset()

func (*EditProfile) String

func (x *EditProfile) String() string

type EditProfileBanner

type EditProfileBanner struct {
	File *media.UploadedFileRef `protobuf:"bytes,1,opt,name=file,proto3,oneof" json:"file,omitempty"`
	// contains filtered or unexported fields
}

settings.editProfileBanner -> ()

func (*EditProfileBanner) Descriptor deprecated

func (*EditProfileBanner) Descriptor() ([]byte, []int)

Deprecated: Use EditProfileBanner.ProtoReflect.Descriptor instead.

func (*EditProfileBanner) GetFile

func (x *EditProfileBanner) GetFile() *media.UploadedFileRef

func (*EditProfileBanner) ProtoMessage

func (*EditProfileBanner) ProtoMessage()

func (*EditProfileBanner) ProtoReflect

func (x *EditProfileBanner) ProtoReflect() protoreflect.Message

func (*EditProfileBanner) Reset

func (x *EditProfileBanner) Reset()

func (*EditProfileBanner) String

func (x *EditProfileBanner) String() string

type EditProfilePhoto

type EditProfilePhoto struct {
	File *media.UploadedFileRef `protobuf:"bytes,1,opt,name=file,proto3,oneof" json:"file,omitempty"`
	// contains filtered or unexported fields
}

settings.editProfilePhoto -> ()

func (*EditProfilePhoto) Descriptor deprecated

func (*EditProfilePhoto) Descriptor() ([]byte, []int)

Deprecated: Use EditProfilePhoto.ProtoReflect.Descriptor instead.

func (*EditProfilePhoto) GetFile

func (x *EditProfilePhoto) GetFile() *media.UploadedFileRef

func (*EditProfilePhoto) ProtoMessage

func (*EditProfilePhoto) ProtoMessage()

func (*EditProfilePhoto) ProtoReflect

func (x *EditProfilePhoto) ProtoReflect() protoreflect.Message

func (*EditProfilePhoto) Reset

func (x *EditProfilePhoto) Reset()

func (*EditProfilePhoto) String

func (x *EditProfilePhoto) String() string

type EditUserSettings

type EditUserSettings struct {
	Settings *UserSettings `protobuf:"bytes,1,opt,name=settings,proto3,oneof" json:"settings,omitempty"`
	// contains filtered or unexported fields
}

settings.editUserSettings -> settings.UserSettings

func (*EditUserSettings) Descriptor deprecated

func (*EditUserSettings) Descriptor() ([]byte, []int)

Deprecated: Use EditUserSettings.ProtoReflect.Descriptor instead.

func (*EditUserSettings) GetSettings

func (x *EditUserSettings) GetSettings() *UserSettings

func (*EditUserSettings) ProtoMessage

func (*EditUserSettings) ProtoMessage()

func (*EditUserSettings) ProtoReflect

func (x *EditUserSettings) ProtoReflect() protoreflect.Message

func (*EditUserSettings) Reset

func (x *EditUserSettings) Reset()

func (*EditUserSettings) String

func (x *EditUserSettings) String() string

type GetAccount

type GetAccount struct {
	// contains filtered or unexported fields
}

settings.getAccount -> settings.Account

func (*GetAccount) Descriptor deprecated

func (*GetAccount) Descriptor() ([]byte, []int)

Deprecated: Use GetAccount.ProtoReflect.Descriptor instead.

func (*GetAccount) ProtoMessage

func (*GetAccount) ProtoMessage()

func (*GetAccount) ProtoReflect

func (x *GetAccount) ProtoReflect() protoreflect.Message

func (*GetAccount) Reset

func (x *GetAccount) Reset()

func (*GetAccount) String

func (x *GetAccount) String() string

type GetMfaMethods

type GetMfaMethods struct {
	// contains filtered or unexported fields
}

settings.getMfaMethods -> settings.MfaMethods

func (*GetMfaMethods) Descriptor deprecated

func (*GetMfaMethods) Descriptor() ([]byte, []int)

Deprecated: Use GetMfaMethods.ProtoReflect.Descriptor instead.

func (*GetMfaMethods) ProtoMessage

func (*GetMfaMethods) ProtoMessage()

func (*GetMfaMethods) ProtoReflect

func (x *GetMfaMethods) ProtoReflect() protoreflect.Message

func (*GetMfaMethods) Reset

func (x *GetMfaMethods) Reset()

func (*GetMfaMethods) String

func (x *GetMfaMethods) String() string

type GetRecoveryCodes

type GetRecoveryCodes struct {
	Password string `protobuf:"bytes,1,opt,name=password,proto3" json:"password,omitempty"`
	// contains filtered or unexported fields
}

settings.getRecoveryCodes -> settings.RecoveryCodes

func (*GetRecoveryCodes) Descriptor deprecated

func (*GetRecoveryCodes) Descriptor() ([]byte, []int)

Deprecated: Use GetRecoveryCodes.ProtoReflect.Descriptor instead.

func (*GetRecoveryCodes) GetPassword

func (x *GetRecoveryCodes) GetPassword() string

func (*GetRecoveryCodes) ProtoMessage

func (*GetRecoveryCodes) ProtoMessage()

func (*GetRecoveryCodes) ProtoReflect

func (x *GetRecoveryCodes) ProtoReflect() protoreflect.Message

func (*GetRecoveryCodes) Reset

func (x *GetRecoveryCodes) Reset()

func (*GetRecoveryCodes) String

func (x *GetRecoveryCodes) String() string

type MfaMethods

type MfaMethods struct {
	TotpEnabled            bool                  `protobuf:"varint,1,opt,name=totp_enabled,json=totpEnabled,proto3" json:"totp_enabled,omitempty"`
	WebauthnCredentials    []*WebauthnCredential `protobuf:"bytes,2,rep,name=webauthn_credentials,json=webauthnCredentials,proto3" json:"webauthn_credentials,omitempty"`
	RecoveryCodesRemaining uint32                `` /* 130-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*MfaMethods) Descriptor deprecated

func (*MfaMethods) Descriptor() ([]byte, []int)

Deprecated: Use MfaMethods.ProtoReflect.Descriptor instead.

func (*MfaMethods) GetRecoveryCodesRemaining

func (x *MfaMethods) GetRecoveryCodesRemaining() uint32

func (*MfaMethods) GetTotpEnabled

func (x *MfaMethods) GetTotpEnabled() bool

func (*MfaMethods) GetWebauthnCredentials

func (x *MfaMethods) GetWebauthnCredentials() []*WebauthnCredential

func (*MfaMethods) ProtoMessage

func (*MfaMethods) ProtoMessage()

func (*MfaMethods) ProtoReflect

func (x *MfaMethods) ProtoReflect() protoreflect.Message

func (*MfaMethods) Reset

func (x *MfaMethods) Reset()

func (*MfaMethods) String

func (x *MfaMethods) String() string

type MfaStepUp

type MfaStepUp struct {
	StepUpToken         *string `protobuf:"bytes,1,opt,name=step_up_token,json=stepUpToken,proto3,oneof" json:"step_up_token,omitempty"`
	ChallengeId         *string `protobuf:"bytes,2,opt,name=challenge_id,json=challengeId,proto3,oneof" json:"challenge_id,omitempty"`
	ExpiresAt           *uint64 `protobuf:"fixed64,3,opt,name=expires_at,json=expiresAt,proto3,oneof" json:"expires_at,omitempty"`
	Totp                bool    `protobuf:"varint,4,opt,name=totp,proto3" json:"totp,omitempty"`
	RecoveryCodes       bool    `protobuf:"varint,5,opt,name=recovery_codes,json=recoveryCodes,proto3" json:"recovery_codes,omitempty"`
	WebauthnOptionsJson *string `` /* 126-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*MfaStepUp) Descriptor deprecated

func (*MfaStepUp) Descriptor() ([]byte, []int)

Deprecated: Use MfaStepUp.ProtoReflect.Descriptor instead.

func (*MfaStepUp) GetChallengeId

func (x *MfaStepUp) GetChallengeId() string

func (*MfaStepUp) GetExpiresAt

func (x *MfaStepUp) GetExpiresAt() uint64

func (*MfaStepUp) GetRecoveryCodes

func (x *MfaStepUp) GetRecoveryCodes() bool

func (*MfaStepUp) GetStepUpToken

func (x *MfaStepUp) GetStepUpToken() string

func (*MfaStepUp) GetTotp

func (x *MfaStepUp) GetTotp() bool

func (*MfaStepUp) GetWebauthnOptionsJson

func (x *MfaStepUp) GetWebauthnOptionsJson() string

func (*MfaStepUp) ProtoMessage

func (*MfaStepUp) ProtoMessage()

func (*MfaStepUp) ProtoReflect

func (x *MfaStepUp) ProtoReflect() protoreflect.Message

func (*MfaStepUp) Reset

func (x *MfaStepUp) Reset()

func (*MfaStepUp) String

func (x *MfaStepUp) String() string

type RecoveryCodes

type RecoveryCodes struct {
	RecoveryCodes []*BackupCode `protobuf:"bytes,1,rep,name=recovery_codes,json=recoveryCodes,proto3" json:"recovery_codes,omitempty"`
	// contains filtered or unexported fields
}

func (*RecoveryCodes) Descriptor deprecated

func (*RecoveryCodes) Descriptor() ([]byte, []int)

Deprecated: Use RecoveryCodes.ProtoReflect.Descriptor instead.

func (*RecoveryCodes) GetRecoveryCodes

func (x *RecoveryCodes) GetRecoveryCodes() []*BackupCode

func (*RecoveryCodes) ProtoMessage

func (*RecoveryCodes) ProtoMessage()

func (*RecoveryCodes) ProtoReflect

func (x *RecoveryCodes) ProtoReflect() protoreflect.Message

func (*RecoveryCodes) Reset

func (x *RecoveryCodes) Reset()

func (*RecoveryCodes) String

func (x *RecoveryCodes) String() string

type RegenerateRecoveryCodes

type RegenerateRecoveryCodes struct {
	StepUpToken string `protobuf:"bytes,1,opt,name=step_up_token,json=stepUpToken,proto3" json:"step_up_token,omitempty"`
	// contains filtered or unexported fields
}

settings.regenerateRecoveryCodes -> settings.RecoveryCodes

func (*RegenerateRecoveryCodes) Descriptor deprecated

func (*RegenerateRecoveryCodes) Descriptor() ([]byte, []int)

Deprecated: Use RegenerateRecoveryCodes.ProtoReflect.Descriptor instead.

func (*RegenerateRecoveryCodes) GetStepUpToken

func (x *RegenerateRecoveryCodes) GetStepUpToken() string

func (*RegenerateRecoveryCodes) ProtoMessage

func (*RegenerateRecoveryCodes) ProtoMessage()

func (*RegenerateRecoveryCodes) ProtoReflect

func (x *RegenerateRecoveryCodes) ProtoReflect() protoreflect.Message

func (*RegenerateRecoveryCodes) Reset

func (x *RegenerateRecoveryCodes) Reset()

func (*RegenerateRecoveryCodes) String

func (x *RegenerateRecoveryCodes) String() string

type RegisterPushSubscription

type RegisterPushSubscription struct {

	// Types that are valid to be assigned to Subscription:
	//
	//	*RegisterPushSubscription_Web
	//	*RegisterPushSubscription_Push_
	Subscription isRegisterPushSubscription_Subscription `protobuf_oneof:"subscription"`
	// contains filtered or unexported fields
}

settings.registerPushSubscription -> ()

func (*RegisterPushSubscription) Descriptor deprecated

func (*RegisterPushSubscription) Descriptor() ([]byte, []int)

Deprecated: Use RegisterPushSubscription.ProtoReflect.Descriptor instead.

func (*RegisterPushSubscription) GetPush

func (*RegisterPushSubscription) GetSubscription

func (x *RegisterPushSubscription) GetSubscription() isRegisterPushSubscription_Subscription

func (*RegisterPushSubscription) GetWeb

func (*RegisterPushSubscription) ProtoMessage

func (*RegisterPushSubscription) ProtoMessage()

func (*RegisterPushSubscription) ProtoReflect

func (x *RegisterPushSubscription) ProtoReflect() protoreflect.Message

func (*RegisterPushSubscription) Reset

func (x *RegisterPushSubscription) Reset()

func (*RegisterPushSubscription) String

func (x *RegisterPushSubscription) String() string

type RegisterPushSubscription_Push

type RegisterPushSubscription_Push struct {
	Type                 RegisterPushSubscription_PushType             `protobuf:"varint,1,opt,name=type,proto3,enum=osmium.client.settings.RegisterPushSubscription_PushType" json:"type,omitempty"`
	Token                string                                        `protobuf:"bytes,2,opt,name=token,proto3" json:"token,omitempty"`
	EncryptionPublicKey  *string                                       `` /* 126-byte string literal not displayed */
	EncryptionAuthSecret *string                                       `` /* 129-byte string literal not displayed */
	EncryptionKeyId      *string                                       `protobuf:"bytes,5,opt,name=encryption_key_id,json=encryptionKeyId,proto3,oneof" json:"encryption_key_id,omitempty"`
	EncryptionScheme     RegisterPushSubscription_PushEncryptionScheme `` /* 184-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*RegisterPushSubscription_Push) Descriptor deprecated

func (*RegisterPushSubscription_Push) Descriptor() ([]byte, []int)

Deprecated: Use RegisterPushSubscription_Push.ProtoReflect.Descriptor instead.

func (*RegisterPushSubscription_Push) GetEncryptionAuthSecret

func (x *RegisterPushSubscription_Push) GetEncryptionAuthSecret() string

func (*RegisterPushSubscription_Push) GetEncryptionKeyId

func (x *RegisterPushSubscription_Push) GetEncryptionKeyId() string

func (*RegisterPushSubscription_Push) GetEncryptionPublicKey

func (x *RegisterPushSubscription_Push) GetEncryptionPublicKey() string

func (*RegisterPushSubscription_Push) GetEncryptionScheme

func (*RegisterPushSubscription_Push) GetToken

func (x *RegisterPushSubscription_Push) GetToken() string

func (*RegisterPushSubscription_Push) GetType

func (*RegisterPushSubscription_Push) ProtoMessage

func (*RegisterPushSubscription_Push) ProtoMessage()

func (*RegisterPushSubscription_Push) ProtoReflect

func (*RegisterPushSubscription_Push) Reset

func (x *RegisterPushSubscription_Push) Reset()

func (*RegisterPushSubscription_Push) String

type RegisterPushSubscription_PushEncryptionScheme

type RegisterPushSubscription_PushEncryptionScheme int32
const (
	RegisterPushSubscription_PUSH_ENCRYPTION_UNKNOWN       RegisterPushSubscription_PushEncryptionScheme = 0
	RegisterPushSubscription_P256_HKDF_SHA256_AES256GCM_V1 RegisterPushSubscription_PushEncryptionScheme = 1
)

func (RegisterPushSubscription_PushEncryptionScheme) Descriptor

func (RegisterPushSubscription_PushEncryptionScheme) Enum

func (RegisterPushSubscription_PushEncryptionScheme) EnumDescriptor deprecated

func (RegisterPushSubscription_PushEncryptionScheme) EnumDescriptor() ([]byte, []int)

Deprecated: Use RegisterPushSubscription_PushEncryptionScheme.Descriptor instead.

func (RegisterPushSubscription_PushEncryptionScheme) Number

func (RegisterPushSubscription_PushEncryptionScheme) String

func (RegisterPushSubscription_PushEncryptionScheme) Type

type RegisterPushSubscription_PushType

type RegisterPushSubscription_PushType int32
const (
	RegisterPushSubscription_UNKNOWN     RegisterPushSubscription_PushType = 0
	RegisterPushSubscription_WEB         RegisterPushSubscription_PushType = 1
	RegisterPushSubscription_IOS         RegisterPushSubscription_PushType = 2
	RegisterPushSubscription_ANDROID_FCM RegisterPushSubscription_PushType = 3
)

func (RegisterPushSubscription_PushType) Descriptor

func (RegisterPushSubscription_PushType) Enum

func (RegisterPushSubscription_PushType) EnumDescriptor deprecated

func (RegisterPushSubscription_PushType) EnumDescriptor() ([]byte, []int)

Deprecated: Use RegisterPushSubscription_PushType.Descriptor instead.

func (RegisterPushSubscription_PushType) Number

func (RegisterPushSubscription_PushType) String

func (RegisterPushSubscription_PushType) Type

type RegisterPushSubscription_Push_

type RegisterPushSubscription_Push_ struct {
	Push *RegisterPushSubscription_Push `protobuf:"bytes,2,opt,name=push,proto3,oneof"`
}

type RegisterPushSubscription_Web

type RegisterPushSubscription_Web struct {
	Web *RegisterPushSubscription_WebPush `protobuf:"bytes,1,opt,name=web,proto3,oneof"`
}

type RegisterPushSubscription_WebPush

type RegisterPushSubscription_WebPush struct {
	Endpoint string `protobuf:"bytes,1,opt,name=endpoint,proto3" json:"endpoint,omitempty"`
	P256Dh   string `protobuf:"bytes,2,opt,name=p256dh,proto3" json:"p256dh,omitempty"`
	Auth     string `protobuf:"bytes,3,opt,name=auth,proto3" json:"auth,omitempty"`
	// contains filtered or unexported fields
}

func (*RegisterPushSubscription_WebPush) Descriptor deprecated

func (*RegisterPushSubscription_WebPush) Descriptor() ([]byte, []int)

Deprecated: Use RegisterPushSubscription_WebPush.ProtoReflect.Descriptor instead.

func (*RegisterPushSubscription_WebPush) GetAuth

func (*RegisterPushSubscription_WebPush) GetEndpoint

func (x *RegisterPushSubscription_WebPush) GetEndpoint() string

func (*RegisterPushSubscription_WebPush) GetP256Dh

func (*RegisterPushSubscription_WebPush) ProtoMessage

func (*RegisterPushSubscription_WebPush) ProtoMessage()

func (*RegisterPushSubscription_WebPush) ProtoReflect

func (*RegisterPushSubscription_WebPush) Reset

func (*RegisterPushSubscription_WebPush) String

type RequestTakeout

type RequestTakeout struct {
	// contains filtered or unexported fields
}

settings.requestTakeout -> ()

func (*RequestTakeout) Descriptor deprecated

func (*RequestTakeout) Descriptor() ([]byte, []int)

Deprecated: Use RequestTakeout.ProtoReflect.Descriptor instead.

func (*RequestTakeout) ProtoMessage

func (*RequestTakeout) ProtoMessage()

func (*RequestTakeout) ProtoReflect

func (x *RequestTakeout) ProtoReflect() protoreflect.Message

func (*RequestTakeout) Reset

func (x *RequestTakeout) Reset()

func (*RequestTakeout) String

func (x *RequestTakeout) String() string

type SetupTotp

type SetupTotp struct {
	Enabled     bool    `protobuf:"varint,1,opt,name=enabled,proto3" json:"enabled,omitempty"`
	Code        *string `protobuf:"bytes,2,opt,name=code,proto3,oneof" json:"code,omitempty"`
	StepUpToken *string `protobuf:"bytes,3,opt,name=step_up_token,json=stepUpToken,proto3,oneof" json:"step_up_token,omitempty"`
	// contains filtered or unexported fields
}

settings.setupTotp -> settings.Totp

func (*SetupTotp) Descriptor deprecated

func (*SetupTotp) Descriptor() ([]byte, []int)

Deprecated: Use SetupTotp.ProtoReflect.Descriptor instead.

func (*SetupTotp) GetCode

func (x *SetupTotp) GetCode() string

func (*SetupTotp) GetEnabled

func (x *SetupTotp) GetEnabled() bool

func (*SetupTotp) GetStepUpToken

func (x *SetupTotp) GetStepUpToken() string

func (*SetupTotp) ProtoMessage

func (*SetupTotp) ProtoMessage()

func (*SetupTotp) ProtoReflect

func (x *SetupTotp) ProtoReflect() protoreflect.Message

func (*SetupTotp) Reset

func (x *SetupTotp) Reset()

func (*SetupTotp) String

func (x *SetupTotp) String() string

type SetupWebauthn

type SetupWebauthn struct {
	Enabled        bool    `protobuf:"varint,1,opt,name=enabled,proto3" json:"enabled,omitempty"`
	CredentialJson *string `protobuf:"bytes,2,opt,name=credential_json,json=credentialJson,proto3,oneof" json:"credential_json,omitempty"`
	// @snowflake<AccountMfa>
	CredentialId *uint64 `protobuf:"fixed64,3,opt,name=credential_id,json=credentialId,proto3,oneof" json:"credential_id,omitempty"`
	DisplayName  *string `protobuf:"bytes,4,opt,name=display_name,json=displayName,proto3,oneof" json:"display_name,omitempty"`
	StepUpToken  *string `protobuf:"bytes,5,opt,name=step_up_token,json=stepUpToken,proto3,oneof" json:"step_up_token,omitempty"`
	ChallengeId  *string `protobuf:"bytes,6,opt,name=challenge_id,json=challengeId,proto3,oneof" json:"challenge_id,omitempty"`
	// contains filtered or unexported fields
}

settings.setupWebauthn -> settings.Webauthn

func (*SetupWebauthn) Descriptor deprecated

func (*SetupWebauthn) Descriptor() ([]byte, []int)

Deprecated: Use SetupWebauthn.ProtoReflect.Descriptor instead.

func (*SetupWebauthn) GetChallengeId

func (x *SetupWebauthn) GetChallengeId() string

func (*SetupWebauthn) GetCredentialId

func (x *SetupWebauthn) GetCredentialId() uint64

func (*SetupWebauthn) GetCredentialJson

func (x *SetupWebauthn) GetCredentialJson() string

func (*SetupWebauthn) GetDisplayName

func (x *SetupWebauthn) GetDisplayName() string

func (*SetupWebauthn) GetEnabled

func (x *SetupWebauthn) GetEnabled() bool

func (*SetupWebauthn) GetStepUpToken

func (x *SetupWebauthn) GetStepUpToken() string

func (*SetupWebauthn) ProtoMessage

func (*SetupWebauthn) ProtoMessage()

func (*SetupWebauthn) ProtoReflect

func (x *SetupWebauthn) ProtoReflect() protoreflect.Message

func (*SetupWebauthn) Reset

func (x *SetupWebauthn) Reset()

func (*SetupWebauthn) String

func (x *SetupWebauthn) String() string

type Totp

type Totp struct {
	Enabled     bool          `protobuf:"varint,1,opt,name=enabled,proto3" json:"enabled,omitempty"`
	Url         *string       `protobuf:"bytes,2,opt,name=url,proto3,oneof" json:"url,omitempty"`
	BackupCodes []*BackupCode `protobuf:"bytes,3,rep,name=backup_codes,json=backupCodes,proto3" json:"backup_codes,omitempty"`
	// contains filtered or unexported fields
}

func (*Totp) Descriptor deprecated

func (*Totp) Descriptor() ([]byte, []int)

Deprecated: Use Totp.ProtoReflect.Descriptor instead.

func (*Totp) GetBackupCodes

func (x *Totp) GetBackupCodes() []*BackupCode

func (*Totp) GetEnabled

func (x *Totp) GetEnabled() bool

func (*Totp) GetUrl

func (x *Totp) GetUrl() string

func (*Totp) ProtoMessage

func (*Totp) ProtoMessage()

func (*Totp) ProtoReflect

func (x *Totp) ProtoReflect() protoreflect.Message

func (*Totp) Reset

func (x *Totp) Reset()

func (*Totp) String

func (x *Totp) String() string

type UnregisterPushSubscription

type UnregisterPushSubscription struct {
	// contains filtered or unexported fields
}

settings.unregisterPushSubscription -> ()

func (*UnregisterPushSubscription) Descriptor deprecated

func (*UnregisterPushSubscription) Descriptor() ([]byte, []int)

Deprecated: Use UnregisterPushSubscription.ProtoReflect.Descriptor instead.

func (*UnregisterPushSubscription) ProtoMessage

func (*UnregisterPushSubscription) ProtoMessage()

func (*UnregisterPushSubscription) ProtoReflect

func (*UnregisterPushSubscription) Reset

func (x *UnregisterPushSubscription) Reset()

func (*UnregisterPushSubscription) String

func (x *UnregisterPushSubscription) String() string

type UserSettings

type UserSettings struct {
	CommunityOrder   *UserSettings_CommunityOrder   `protobuf:"bytes,1,opt,name=community_order,json=communityOrder,proto3,oneof" json:"community_order,omitempty"`
	EmailPreferences *UserSettings_EmailPreferences `protobuf:"bytes,2,opt,name=email_preferences,json=emailPreferences,proto3,oneof" json:"email_preferences,omitempty"`
	// contains filtered or unexported fields
}

func (*UserSettings) Descriptor deprecated

func (*UserSettings) Descriptor() ([]byte, []int)

Deprecated: Use UserSettings.ProtoReflect.Descriptor instead.

func (*UserSettings) GetCommunityOrder

func (x *UserSettings) GetCommunityOrder() *UserSettings_CommunityOrder

func (*UserSettings) GetEmailPreferences

func (x *UserSettings) GetEmailPreferences() *UserSettings_EmailPreferences

func (*UserSettings) ProtoMessage

func (*UserSettings) ProtoMessage()

func (*UserSettings) ProtoReflect

func (x *UserSettings) ProtoReflect() protoreflect.Message

func (*UserSettings) Reset

func (x *UserSettings) Reset()

func (*UserSettings) String

func (x *UserSettings) String() string

type UserSettings_CommunityOrder

type UserSettings_CommunityOrder struct {

	// @snowflake<Community>
	CommunityIds []uint64 `protobuf:"fixed64,1,rep,packed,name=community_ids,json=communityIds,proto3" json:"community_ids,omitempty"`
	// contains filtered or unexported fields
}

func (*UserSettings_CommunityOrder) Descriptor deprecated

func (*UserSettings_CommunityOrder) Descriptor() ([]byte, []int)

Deprecated: Use UserSettings_CommunityOrder.ProtoReflect.Descriptor instead.

func (*UserSettings_CommunityOrder) GetCommunityIds

func (x *UserSettings_CommunityOrder) GetCommunityIds() []uint64

func (*UserSettings_CommunityOrder) ProtoMessage

func (*UserSettings_CommunityOrder) ProtoMessage()

func (*UserSettings_CommunityOrder) ProtoReflect

func (*UserSettings_CommunityOrder) Reset

func (x *UserSettings_CommunityOrder) Reset()

func (*UserSettings_CommunityOrder) String

func (x *UserSettings_CommunityOrder) String() string

type UserSettings_EmailPreferences

type UserSettings_EmailPreferences struct {

	// Transactional emails for missed calls, messages, and friend requests.
	CommunicationEmails *bool `protobuf:"varint,1,opt,name=communication_emails,json=communicationEmails,proto3,oneof" json:"communication_emails,omitempty"`
	// Promotion emails for update announcements.
	AnnouncementEmails *bool `protobuf:"varint,2,opt,name=announcement_emails,json=announcementEmails,proto3,oneof" json:"announcement_emails,omitempty"`
	// contains filtered or unexported fields
}

func (*UserSettings_EmailPreferences) Descriptor deprecated

func (*UserSettings_EmailPreferences) Descriptor() ([]byte, []int)

Deprecated: Use UserSettings_EmailPreferences.ProtoReflect.Descriptor instead.

func (*UserSettings_EmailPreferences) GetAnnouncementEmails

func (x *UserSettings_EmailPreferences) GetAnnouncementEmails() bool

func (*UserSettings_EmailPreferences) GetCommunicationEmails

func (x *UserSettings_EmailPreferences) GetCommunicationEmails() bool

func (*UserSettings_EmailPreferences) ProtoMessage

func (*UserSettings_EmailPreferences) ProtoMessage()

func (*UserSettings_EmailPreferences) ProtoReflect

func (*UserSettings_EmailPreferences) Reset

func (x *UserSettings_EmailPreferences) Reset()

func (*UserSettings_EmailPreferences) String

type Webauthn

type Webauthn struct {
	OptionsJson   *string             `protobuf:"bytes,1,opt,name=options_json,json=optionsJson,proto3,oneof" json:"options_json,omitempty"`
	Credential    *WebauthnCredential `protobuf:"bytes,2,opt,name=credential,proto3,oneof" json:"credential,omitempty"`
	RecoveryCodes []*BackupCode       `protobuf:"bytes,3,rep,name=recovery_codes,json=recoveryCodes,proto3" json:"recovery_codes,omitempty"`
	ChallengeId   *string             `protobuf:"bytes,4,opt,name=challenge_id,json=challengeId,proto3,oneof" json:"challenge_id,omitempty"`
	// contains filtered or unexported fields
}

func (*Webauthn) Descriptor deprecated

func (*Webauthn) Descriptor() ([]byte, []int)

Deprecated: Use Webauthn.ProtoReflect.Descriptor instead.

func (*Webauthn) GetChallengeId

func (x *Webauthn) GetChallengeId() string

func (*Webauthn) GetCredential

func (x *Webauthn) GetCredential() *WebauthnCredential

func (*Webauthn) GetOptionsJson

func (x *Webauthn) GetOptionsJson() string

func (*Webauthn) GetRecoveryCodes

func (x *Webauthn) GetRecoveryCodes() []*BackupCode

func (*Webauthn) ProtoMessage

func (*Webauthn) ProtoMessage()

func (*Webauthn) ProtoReflect

func (x *Webauthn) ProtoReflect() protoreflect.Message

func (*Webauthn) Reset

func (x *Webauthn) Reset()

func (*Webauthn) String

func (x *Webauthn) String() string

type WebauthnCredential

type WebauthnCredential struct {

	// @snowflake<AccountMfa>
	Id           uint64  `protobuf:"fixed64,1,opt,name=id,proto3" json:"id,omitempty"`
	CredentialId string  `protobuf:"bytes,2,opt,name=credential_id,json=credentialId,proto3" json:"credential_id,omitempty"`
	DisplayName  string  `protobuf:"bytes,3,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	CreatedAt    uint64  `protobuf:"fixed64,4,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	LastUsedAt   *uint64 `protobuf:"fixed64,5,opt,name=last_used_at,json=lastUsedAt,proto3,oneof" json:"last_used_at,omitempty"`
	// contains filtered or unexported fields
}

func (*WebauthnCredential) Descriptor deprecated

func (*WebauthnCredential) Descriptor() ([]byte, []int)

Deprecated: Use WebauthnCredential.ProtoReflect.Descriptor instead.

func (*WebauthnCredential) GetCreatedAt

func (x *WebauthnCredential) GetCreatedAt() uint64

func (*WebauthnCredential) GetCredentialId

func (x *WebauthnCredential) GetCredentialId() string

func (*WebauthnCredential) GetDisplayName

func (x *WebauthnCredential) GetDisplayName() string

func (*WebauthnCredential) GetId

func (x *WebauthnCredential) GetId() uint64

func (*WebauthnCredential) GetLastUsedAt

func (x *WebauthnCredential) GetLastUsedAt() uint64

func (*WebauthnCredential) ProtoMessage

func (*WebauthnCredential) ProtoMessage()

func (*WebauthnCredential) ProtoReflect

func (x *WebauthnCredential) ProtoReflect() protoreflect.Message

func (*WebauthnCredential) Reset

func (x *WebauthnCredential) Reset()

func (*WebauthnCredential) String

func (x *WebauthnCredential) String() string

Jump to